Module: Vox::HTTP::Routes::Voice
- Defined in:
- lib/vox/http/routes/voice.rb
Overview
Mixin for voice routes.
Instance Method Summary collapse
-
#list_voice_regions ⇒ Array<Hash<Symbol, Object>>
Lists voice regions that can be used when creating guilds.
Instance Method Details
#list_voice_regions ⇒ Array<Hash<Symbol, Object>>
Lists voice regions that can be used when creating guilds.
15 16 17 18 |
# File 'lib/vox/http/routes/voice.rb', line 15 def list_voice_regions route = Route.new(:GET, '/voice/regions') request(route) end |